Layout

Struct Layout 

pub struct Layout {
    pub size: usize,
    pub align: Align,
}
Layout of a block of memory.

Fields

size: usize

The minimum size in bytes for a memory block of this layout.

align: Align

The minimum byte alignment for a memory block of this layout.

Implementations

Source

impl Layout

pub const fn of<T>() -> Self

Returns the layout of a concrete type.

Uses core::mem::size_of and core::mem::align_of.

pub const fn list<T>(len: usize) -> Self

Creates a layout describing a list of T that is len elements long.