pub struct Layout {
pub size: usize,
pub align: Align,
}Expand description
Layout of a block of memory.
Fields
size: usizeThe minimum size in bytes for a memory block of this layout.
align: AlignThe minimum byte alignment for a memory block of this layout.
Implementations
Sourceimpl Layout
impl Layout
Sourcepub const fn of<T>() -> Self
pub const fn of<T>() -> Self
Returns the layout of a concrete type.
Uses core::mem::size_of and core::mem::align_of.